### Description

Describe your feature.

### Motivation

Describe your use case(s).

---

You can also find us on [Slack](https://join.slack.com/t/quantify-hq/shared_invite/zt-vao45946-f_NaRc4mvYQDQE_oYB8xSw).
For reference, the issues workflow is described in the [contribution guidelines](https://quantify-quantify-core.readthedocs-hosted.com/en/main/contributing.html#issues-workflow).
